@@ -1,13 +1,14 @@
 /*
- * Copyright (c) 2001 Qualcomm Incorporated.  All rights reserved.
+ * Copyright (c) 2003 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  *
  * Revisions:
  *
- *     07/25/01 [RCG]
- *             - Restrict clear-text-password=never to APOP.
- *             - Restrict clear-text-password=tls to QPOP_SSL
+ *     08/06/02  [rcg]
+ *             - Added ability to set OpenSSL options (SSL_OP_* values).
+ *               Note that unlike other options, if this is set more
+ *               than once, the values are added together.
  *
  *     06/01/01 [RCG]
  *             - Added 'uw-kludge' as synonym for 'uw-kluge'.
@@ -85,6 +86,11 @@
 #include <string.h>
 #include <errno.h>
 #include <ctype.h>
+#include <limits.h>
+
+#ifdef        QPOP_OPENSSL
+#  include <openssl/ssl.h>
+#endif     /* QPOP_OPENSSL */
 
 #include "popper.h"
 #include "utils.h"
@@ -192,6 +198,8 @@ typedef enum
     kTLS_PRIVKEYFILE,       /*    (no flag)     */
     kTLS_CIPHERLIST,        /*    (no flag)     */
     kTLS_VERSION,           /*    (no flag)     */
+    kTLS_WORKAROUNDS,       /*    (no flag)     */
+    kTLS_OPTIONS,           /*    (no flag)     */
     kDO_TIMING,             /*    (no flag)     */
     kCHECK_OLD_SPOOL_LOC,   /*    (no flag)     */
     kCHECK_HASH_DIR,        /*    (no flag)     */
@@ -285,6 +293,8 @@ static config_table options [] =
     { "tls-server-cert-file"         , CfgStr  , CfgResInit, kTLS_SERVCERTFILE   },
     { "tls-support"                  , CfgMnem , CfgResInit, kTLS_SUPPORT        },
     { "tls-version"                  , CfgMnem , CfgResInit, kTLS_VERSION        },
+    { "tls-workarounds"              , CfgBool , CfgResUser, kTLS_WORKAROUNDS    },
+    { "tls-options"                  , CfgInt  , CfgResUser, kTLS_OPTIONS        },
     { "tracefile"                    , CfgStr  , CfgResNone, kTRACENAME          },
     { "trim-domain"                  , CfgBool , CfgResUser, kTRIMDOMAIN         },
     { "update-on-abort"              , CfgBool , CfgResNone, kUPDATE_ON_ABORT    },
@@ -325,16 +335,9 @@ typedef struct {
 static mnemonic_map mnem_map_clear_text_pwd [] =
 {
     { "default"         , ClearTextDefault      },
-
-#if defined(APOP) || defined(SCRAM)
     { "never"           , ClearTextNever        },
-#endif /* APOP or SCRAM */
-
-#ifdef    QPOP_SSL
     { "TLS"             , ClearTextTLS          },
     { "SSL"             , ClearTextTLS          },
-#endif /* QPOP_SSL */
-
     { "always"          , ClearTextAlways       },
     { "local"           , ClearTextLocal        },
 
@@ -427,6 +430,11 @@ typedef union
 extern int no_rev_lookup;
 extern int pop_timeout;
 
+/*
+ * Kluge temporary value for items we map to others
+ */
+static int gTempVal = 0;
+
 
 /*
  * Prototypes (static to permit auto-inlining by optimizing compilers)
@@ -827,6 +835,11 @@ get_opt_ptr ( POP *p, opt_val_type item )
 #define R__PTR(x) ret_val.pPtr=(x);break
 #define R__MNM(x) ret_val.pInt=((int*)(x));break
 
+    /*
+     * First reset the temp global, in case we return a pointer to it.
+     */
+    gTempVal = 0;
+
     switch ( item )
     {
         case kBULLDIR:             R__PTR ( &p->bulldir );
@@ -864,6 +877,8 @@ get_opt_ptr ( POP *p, opt_val_type item )
         case kTLS_PRIVKEYFILE:     R__PTR ( &p->tls_private_key_file );
         case kTLS_CIPHERLIST:      R__PTR ( &p->tls_cipher_list );
         case kTLS_VERSION:         R__MNM ( &p->tls_version );
+        case kTLS_WORKAROUNDS:     R__INT ( &gTempVal );
+        case kTLS_OPTIONS:         R__INT ( &gTempVal );
         case kDO_TIMING:           R__BOO ( &p->bDo_timing );
         case kCHECK_OLD_SPOOL_LOC: R__BOO ( &p->bCheck_old_spool_loc );
         case kCHECK_HASH_DIR:      R__BOO ( &p->bCheck_hash_dir );
@@ -995,8 +1010,8 @@ show_result ( POP *p, config_table *opt, int iVal, const char *sVal, WHENCE )
 
         case CfgInt:
             if ( p->debug )
-                pop_log ( p, POP_DEBUG, fn, ln, "Set %s to %d",
-                          opt->name, iVal );
+                pop_log ( p, POP_DEBUG, fn, ln, "Set %s to %d (%#0x)",
+                          opt->name, iVal, iVal );
             break;
 
         case CfgMnem:
@@ -1051,7 +1066,16 @@ handle_value ( POP              *p,
      */
     if ( isdigit ( (int) *pval ) )
     {
-        iVal     = atol ( pval );
+        char *EndPtr = NULL;
+        iVal     = strtol ( pval, &EndPtr, 0 );
+        if ( iVal == LONG_MAX || iVal == LONG_MIN 
+                              || ( iVal == 0 && errno == EINVAL ) )
+        {
+            pop_log ( p, POP_PRIORITY, HERE,
+                      "Invalid value for %s: %.*s",
+                      opt_ent->name, plen, pval );
+            return kER_BAD_VAL;
+        }
         val_type = CfgInt;
     }
     else
@@ -1132,14 +1156,18 @@ handle_value ( POP              *p,
         case kTLS_PASSPHRASE:
             return kER_NOT_COMPILED_WITH;
 #endif /* not QPOP_SSLPLUS */
-            break;
 
 #ifndef       QPOP_OPENSSL
         case kTLS_SERVCERTFILE:
         case kTLS_PRIVKEYFILE:
+        case kTLS_OPTIONS:
             return kER_NOT_COMPILED_WITH;
 #endif /* not QPOP_OPENSSL */
-            break;
+
+#if       ! ( defined ( QPOP_OPENSSL ) && defined ( SSL_OP_ALL ) )
+        case kTLS_WORKAROUNDS:
+            return kER_NOT_COMPILED_WITH;
+#endif /* ! ( defined ( QPOP_OPENSSL ) && defined ( SSL_OP_ALL ) ) */
 
         default:
             break;
@@ -1256,6 +1284,22 @@ handle_value ( POP              *p,
 #endif /* SYSLOG42 */
             break;
 
+#ifdef        QPOP_OPENSSL
+        case kTLS_WORKAROUNDS: /* Set tls_options to SSL_OP_ALL */
+            if ( gTempVal )
+            {
+                p->tls_options = SSL_OP_ALL;
+                DEBUG_LOG1 ( p, "set tls-options to %#0x", p->tls_options );
+            }
+            break;
+
+        case kTLS_OPTIONS: /* Add current value to options */
+            p->tls_options += gTempVal;
+            DEBUG_LOG2 ( p, "added %#0x to tls-options (now %#0x)",
+                         gTempVal, p->tls_options );
+            break;
+#endif     /* QPOP_OPENSSL */
+
         default:
             break;
     } /* switch ( opt_ent->value ) */
