@@ -8,12 +8,16 @@
 
 
 /*
- * Copyright (c) 2001 Qualcomm Incorporated.  All rights reserved.
+ * Copyright (c) 2003 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  *
  * Revisions:
  *
+ *     02/06/03 [RCG]
+ *              - Apply patch from Jeremy Chadwick to fix pathname
+ *                trimming of arg[0].
+ *
  *     07/25/01 [RCG]
  *              - Allow '-p' to be used even if APOP not defined.
  *
@@ -666,7 +670,15 @@ char    **      argmessage;
     /*  
      * Save my name in a global variable 
      */
-    p->myname         = argmessage [ 0 ];
+    p->myname = argmessage [ 0 ];
+    if ( p->myname != NULL && *p->myname != '\0' )
+    {
+        char *ptr = NULL;
+        ptr = strrchr ( p->myname, '/' );
+        if ( ptr != NULL && strlen(ptr) > 1 )
+            p->myname = ptr + 1;
+    }
+
 
     /*  
      * Open the log file 
