@@ -6,12 +6,16 @@
 
 
 /*
- * Copyright (c) 2001 Qualcomm Incorporated.  All rights reserved.
+ * Copyright (c) 2003 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  *
  * Revisions:
  *
+ *     01/16/03  [rcg]
+ *             - Renamed PASSWD macro to QPASSWD to avoid redefining
+ *               PASSWD in shadow.h.
+ *
  *     06/01/01  [rcg]
  *             - Added patch by Clifton Royston to change error message
  *               for nonauthfile and authfile tests.
@@ -739,7 +743,7 @@ struct passwd *pw;
 
 #    include <prot.h>
 
-#    define PASSWD(p)       p->ufld.fd_encrypt
+#    define QPASSWD(p)      p->ufld.fd_encrypt
 
 static int
 auth_user ( p, pw )
@@ -773,13 +777,13 @@ struct passwd *pw;
          *
          * Compare the supplied password with the password file entry 
          */
-        if ( ( PASSWD(pr) == NULL ) || ( *PASSWD(pr) == '\0' ) ) {
+        if ( ( QPASSWD(pr) == NULL ) || ( *QPASSWD(pr) == '\0' ) ) {
             sleep  ( SLEEP_SECONDS );
             return ( pop_msg ( p, POP_FAILURE, HERE, ERRMSG_PW, p->user ) );
         }
         
-        if ( strcmp ( bigcrypt ( p->pop_parm[1], PASSWD(pr) ), PASSWD(pr) ) &&
-             strcmp ( crypt    ( p->pop_parm[1], PASSWD(pr) ), PASSWD(pr) )  ) {
+        if ( strcmp ( bigcrypt ( p->pop_parm[1], QPASSWD(pr) ), QPASSWD(pr) ) &&
+             strcmp ( crypt    ( p->pop_parm[1], QPASSWD(pr) ), QPASSWD(pr) )  ) {
             sleep  ( SLEEP_SECONDS );
             return ( pop_msg ( p, POP_FAILURE, HERE, ERRMSG_PW, p->user ) );
         }
@@ -848,7 +852,7 @@ POP     *   p;
 #      include <sys/security.h>
 #      include <prot.h>
 
-#      define   PASSWD(p)   (p->ufld.fd_encrypt)
+#      define   QPASSWD(p)   (p->ufld.fd_encrypt)
 
 static int
 auth_user ( p, pw )
@@ -864,7 +868,7 @@ struct passwd *pw;
             return ( pop_msg ( p, POP_FAILURE, HERE, ERRMSG_PW, p->user ) );
         }
     } else {
-        pw->pw_passwd = (char *)strdup(PASSWD(pr));
+        pw->pw_passwd = (char *)strdup(QPASSWD(pr));
     }
 
     /*  
