@@ -1,10 +1,14 @@
 /*
- * Copyright (c) 2002 QUALCOMM Incorporated. All rights reserved.
+ * Copyright (c) 2003 QUALCOMM Incorporated. All rights reserved.
  * See License.txt file for terms and conditions for modification and
  * redistribution.
  *
  * Revisions: 
  *
+ * 08/06/02  [rcg]
+ *         - Added ability to set options (SSL_OP_* values).
+ *         - Added debug trace call to show OpenSSL library version.
+ *
  * 05/13/01  [rcg]
  *         - Don't call SSL_shutdown unless we tried to negotiate an
  *           SSL session.  (As suggested by Kenneth Porter.)
@@ -54,6 +58,7 @@
 
 #ifdef    QPOP_OPENSSL
 #    include <openssl/ssl.h>
+#    include <openssl/opensslv.h>
 #    include <openssl/err.h>
 #    include <openssl/rand.h>
 #    include <openssl/crypto.h>
@@ -221,7 +226,8 @@ openssl_init ( pop_tls *pTLS, POP *pPOP )
     /*
      * First, initialize the SSL library
      */
-    DEBUG_LOG0 ( pPOP, "...Initializing OpenSSL library" );
+    DEBUG_LOG1 ( pPOP, "...Initializing OpenSSL library (version %s)",
+                 OPENSSL_VERSION_TEXT );
     SSL_load_error_strings();
     SSL_library_init(); /* always returns 1, no need to check */
 
@@ -340,6 +346,16 @@ openssl_init ( pop_tls *pTLS, POP *pPOP )
         goto Done;
     }
 
+    /*
+     * Set desired options
+     */
+    if ( pPOP->tls_options ) {
+        long opts = 0;
+        opts = SSL_CTX_set_options ( pTLS->m_OpenSSLctx, pPOP->tls_options );
+        DEBUG_LOG2 ( pPOP, "...set options %#0x; options now %#0lx",
+                     pPOP->tls_options, opts );
+    }
+
     /*
      * Establish the certificate for our server cert.
      */
