@@ -5,7 +5,7 @@
  */
  
 /*
- * Copyright (c) 2001 Qualcomm Incorporated.  All rights reserved.
+ * Copyright (c) 2003 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  */
@@ -627,6 +627,7 @@ struct _pop {                                   /*  POP parameter block */
     char            *   tls_passphrase;         /* To decrypt private key  */
     char            *   tls_cipher_list;        /* To restrict ciphers */
     tls_vers_type       tls_version;            /* To restrict TLS/SSL versions */
+    int                 tls_options;            /* Desired SSL_OP_ bit flags */
 
 #ifdef SCRAM
     char                cchal[ MAXLINELEN ];    /* plain text client challenge */ 
@@ -841,7 +842,8 @@ typedef struct {
 }MDEFRecordType;              /* To maintain MDEF Array defined 
                                  in pop_extend.c. Used by pop_parse
                                  for expansion. */
-#define MAX_MDEF_INDEX 10
+enum { MAX_MDEF_INDEX = 10 };
+enum { MAX_MDEF_NAME  = 100 };
 
 
 MsgInfoList *msg_ptr ( POP *p, int msg_num );
